#
# spec file for package firebird
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define upversion 2.5.6.27020
%define pkgversion Firebird-%{upversion}-0

%if 0%{?suse_version} < 1130
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%endif

Name:           firebird
Version:        %{upversion}
Release:        15.2
Source:         %{pkgversion}.tar.xz
Source1:        README.SUSE
Source99:       baselibs.conf
Url:            http://www.firebirdsql.org/
BuildRequires:  gcc-c++
BuildRequires:  libedit-devel
BuildRequires:  libicu-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  xz
%ifnarch %{ix86} x86_64
BuildRequires:  libatomic-ops-devel
%endif
Requires(pre):  pwdutils
Requires:       %{name}-server = %{version}
Summary:        An SQL database server
License:        SUSE-IDPL-1.0 and SUSE-IBPL-1.0
Group:          Productivity/Databases/Servers

# SUSE specific patches
Patch1:         allow-creating-buildRoot-as-non-root-user.patch
Patch2:         fbguard-allow-creating-a-guard-pidfile.patch
Patch3:         use-killproc-in-stop-branch-of-SuSE-init-script.patch
Patch4:         disable-xinetd-service-by-default.patch
Patch5:         do-not-use-DatabaseAccess-Full-in-default-config.patch
Patch6:         add-pkgconfig-files.patch
# backport from upstream 3.0 branch
Patch21:        Fixed-CORE-3431-ISQL-pads-UTF-8-data-incorrectly.patch
Patch22:        isql-fix-output-if-charset-is-different-from-locale.patch
Patch23:        isql-fix-buffer-overflow-when-set-width-sets-bigger-.patch
# SUSE only, 2.5 only
Patch31:        add-experimental-support-for-m68k-architecture.patch
# bug fixes
Patch41:        Backported-fix-for-CORE-5474-Restrict-UDF-is-not-eff.patch

%description
Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%prep
%setup -q -n %{pkgversion}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch31 -p1
%patch41 -p1

%build
rm -vf builds/make.new/config/config.{guess,sub}
./autogen.sh --prefix=%{_prefix} \
  --enable-superserver \
  --with-system-icu --with-system-editline \
  --with-fbbin=%{_bindir} --with-fbsbin=%{_sbindir} \
  --with-fbconf=%{_sysconfdir}/%{name} \
  --with-fblib=%{_libdir} --with-fbinclude=%{_includedir}/%{name} \
  --with-fbdoc=%{_docdir}/%{name} \
  --with-fbudf=%{_libdir}/%{name}/udf \
  --with-fbsample=%{_docdir}/%{name}/sample \
  --with-fbsample-db=%{_libdir}/%{name}/sample \
  --with-fbhelp=%{_libdir}/%{name}/lib \
  --with-fbintl=%{_libdir}/%{name}/intl \
  --with-fbmisc=%{_datadir}/%{name}/misc \
  --with-fbsecure-db=%{_localstatedir}/lib/%{name}/secdb \
  --with-fbmsg=%{_libdir}/%{name}/lib \
  --with-fblog=%{_localstatedir}/log/%{name} \
  --with-fbglock=%{_localstatedir}/run/%{name} \
  --with-fbplugins=%{_libdir}/%{name}/plugins
make %{?jobs:CPU=%jobs}
cd gen
make -f Makefile.install buildRoot
chmod -R u+w buildroot%{_docdir}/%{name}

%install
cp -r gen/buildroot/* ${RPM_BUILD_ROOT}/
mkdir -p ${RPM_BUILD_ROOT}/etc/init.d
install -m 755 gen/install/misc/firebird.init.d.suse \
  ${RPM_BUILD_ROOT}/etc/init.d/firebird
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig
cp -v gen/install/misc/*.pc ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/
cd ${RPM_BUILD_ROOT}
mkdir -p .%{_libdir}/%{name}/utils
mv -v .%{_sbindir}/*.sh .%{_libdir}/%{name}/utils/
mv -v .%{_sbindir}/fb_config .%{_libdir}/%{name}/utils/
mv -v .%{_bindir}/isql .%{_bindir}/isql-fb
mv -v .%{_bindir}/gstat .%{_bindir}/gstat-fb
rm -vf .%{_includedir}/%{name}/perf.h
rm -vf .%{_libdir}/libicu*.so
rm -vf .%{_includedir}/*.h
chmod -R u+w .%{_docdir}/%{name}
rm -vf .%{_datadir}/%{name}/misc/firebird.init.*
rm -vf .%{_datadir}/%{name}/misc/rc.config.firebird
rm -vf .%{_datadir}/%{name}/misc/firebird.xinetd
mv -v .%{_sysconfdir}/%{name}/README .%{_sysconfdir}/%{name}/WhatsNew \
  .%{_docdir}/%{name}/
mv -v .%{_sysconfdir}/%{name}/IDPLicense.txt .%{_docdir}/%{name}/
mv -v .%{_sysconfdir}/%{name}/IPLicense.txt .%{_docdir}/%{name}/
cp -v %{S:1} .%{_docdir}/%{name}/
mkdir -p srv/%{name}
ln -s /etc/init.d/firebird usr/sbin/rcfirebird

%files
%defattr(-,root,root)
%{_sbindir}/fbguard
%{_sbindir}/rcfirebird
%{_libdir}/%{name}/utils
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_libdir}/libib_util.so
%dir %{_libdir}/%{name}
%dir %{_datadir}/%{name}
%{_libdir}/%{name}/lib
%{_libdir}/%{name}/intl
%{_datadir}/%{name}/misc
%{_libdir}/%{name}/plugins
%{_libdir}/%{name}/udf
%attr(755,root,root) /etc/init.d/firebird
%{_docdir}/%{name}/IDPLicense.txt
%{_docdir}/%{name}/IPLicense.txt
%{_docdir}/%{name}/README.SUSE

%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/secdb
%attr(0600,firebird,firebird) %config(noreplace) %{_localstatedir}/lib/%{name}/secdb/security2.fdb
%dir %{_libdir}/%{name}/sample
%attr(0600,firebird,firebird) %{_libdir}/%{name}/sample/*
%attr(0750,firebird,firebird) %{_localstatedir}/log/%{name}
%dir %attr(0750,firebird,firebird) /srv/firebird

%pre
getent group firebird >/dev/null || groupadd -r firebird || :
getent passwd firebird >/dev/null \
  || /usr/sbin/useradd -r -g firebird -c 'Firebird SQL server' \
       -d /srv/firebird firebird \
  || :
exit 0

%post
%restart_on_update

%preun
%stop_on_removal

%postun
%restart_on_update
%insserv_cleanup

# ----------------------------------------------------------------------------

%package superserver
Conflicts:      %{name}-classic
Requires:       %{name} = %{version}
Provides:       %{name}-server
Summary:        SuperServer architecture binaries for Firebird SQL server
Group:          Productivity/Databases/Servers

%description superserver
SuperServer architecture binaries for Firebird SQL server. SuperServer
architecture uses one multithreaded process for processing client
connections with exclusive database lock and cache shared between
connections.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files superserver
%defattr(-,root,root)
%{_bindir}/*
%{_sbindir}/fbserver
%{_sbindir}/fbmgr.bin
%{_sbindir}/fb_lock_print

# ----------------------------------------------------------------------------

%package devel
Summary:        UDF support library for Firebird SQL server
Group:          Development/Libraries/C and C++

%description devel
This package is needed for development of client applications and user
defined functions (UDF) for Firebird SQL server.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_docdir}/%{name}/sample

# ----------------------------------------------------------------------------

%package doc
Requires:       %{name} = %{version}
Summary:        Documentation for Firebird SQL server
Group:          Documentation/Other
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description doc
Documentation for Firebird SQL server.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files doc
%defattr(-,root,root)
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/sample
%exclude %{_docdir}/%{name}/IDPLicense.txt
%exclude %{_docdir}/%{name}/IPLicense.txt
%exclude %{_docdir}/%{name}/README.SUSE

# ----------------------------------------------------------------------------

%package -n libfbclient2
Summary:        Firebird SQL server client library
Group:          Development/Libraries/C and C++

%description -n libfbclient2
Shared client library for Firebird SQL server.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files -n libfbclient2
%defattr(-,root,root)
%{_libdir}/libfbclient.so.*

%post -n libfbclient2
/sbin/ldconfig

%postun -n libfbclient2
/sbin/ldconfig

# ----------------------------------------------------------------------------

%package -n libfbclient2-devel
Summary:        Development libraries and headers for Firebird SQL server
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel
Requires:       libfbclient2 = %{version}

%description -n libfbclient2-devel
Development files for Firebird SQL server client library.
 
Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files -n libfbclient2-devel
%defattr(-,root,root)
%{_libdir}/libfbclient.so
%{_libdir}/pkgconfig/fbclient.pc

%changelog
* Tue Feb  7 2017 mkubecek@suse.cz
- Backported-fix-for-CORE-5474-Restrict-UDF-is-not-eff.patch:
  security vulnerability fix for bypassing 'Restrict UDF' value of
  UdfAccess config directive (bsc#1023990)
* Thu Jul  7 2016 mkubecek@suse.cz
- update to upstream 2.5.6 point release
  * CORE-4904: Index corruption could occur while inserting data
    into a long-key-indexed field
  * CORE-4982: The server could crash during "select from
    procedure" if an exception were thrown while backing out the
    current savepoint
  * CORE-4869: A segmentation fault could occur when cleaning the
    metadata cache
  * CORE-4656: The server could hang while chasing dead record
    versions
  * CORE-4680: Deadlock could occur during attachment
  * CORE-4754: Bugcheck 167 (invalid SEND request) could occur
    while working with a GTT from several attachments, using
    EXECUTE STATEMENT ... ON EXTERNAL and different roles
  * CORE-4908: The server could hang on simultaneous connection to
    the Services API and a database
  * fix gbak returning 0 on some errors
  * CORE-5157: The server could go into an infinite loop when data
    were sent from a client to the service in small packets
  * CORE-4645: Source of the error "Bugcheck 165 (cannot find TIP
    page)" was identified and fixed
  * CORE-5240: A crash could occur while restoring a database with
    large page cache
  * CORE-5117: Firebird embedded could crash on unload if it was
    used to make a client connection to a full server
  * CORE-5087: Database shutdown could cause a server crash if
    multiple attachments were running EXECUTE STATEMENT
  * CORE-5068: regression: when gbak was run via the services
    manager with an invalid parameter, it would crash the server.
  * CORE-4983: The server could crash during execution of an
    unprepared statement
  * CORE-5216: improvement: Run-time errors raised inside EXECUTE
    BLOCK now provide the location context (line/column numbers)
  * CORE-4978: improvement: Improve validation and fixup of lost
    data pages
- drop patches included in upstream point release:
  Added-check-for-failed-fork-system-call.patch
  Apply-Partial-patch-for-C-11-compilation-of-the-Fire.patch
  Backported-fix-for-CORE-4785-Bad-packet-of-op_execut.patch
  Backported-fix-for-CORE-4788-Superclassic-server-han.patch
  Firebird-2.5.4.26856-0.tar.xz
  Fixed-s-tandalone-switch-in-posix-server.patch
  Libreoffice-patch-C-11-new-delete-replacement-functi.patch
* Mon Jul 27 2015 mkubecek@suse.cz
- fix libfbembed package name in baselibs.conf so that the
  libfbembed2_5-32bit is built
* Mon Jul 27 2015 mkubecek@suse.cz
- upgrade to upstream version 2.5.4 (final)
  * CORE-4558: SuperServer dies when client is disconnected
    abnormally during the index navigational scan
  * CORE-4676: Crash on unexpected client disconnection with opened
    transaction
  * CORE-4075: Server bugchecks or crashes on exception in
    calculated index
  * CORE-4624: Firebird handles ':' characters in mount table
    entries invalid
- Backported-fix-for-CORE-4788-Superclassic-server-han.patch:
  CORE-4788: Superclassic server hangs when receiving network
  packet
- Backported-fix-for-CORE-4785-Bad-packet-of-op_execut.patch:
  CORE-4785: Bad packet of op_execute kills the server
- Fixed-s-tandalone-switch-in-posix-server.patch:
  fix -s(tandalone) switch in posix server
- Added-check-for-failed-fork-system-call.patch:
  add check for failed fork() system call
- Apply-Partial-patch-for-C-11-compilation-of-the-Fire.patch:
  Libreoffice-patch-C-11-new-delete-replacement-functi.patch:
  two patches from LibreOffice fixing C++11 build
* Sun Dec  7 2014 mkubecek@suse.cz
- upgrade to upstream version 2.5.4.26821
  * server crash by malformed packet (bnc#908127, CORE-4029,
    CORE-4030)
  * various functional fixes
- removed patches merged into upstream:
  * Firebird-2.5.2.26539-0-fix-bashisms.patch:
  * aarch64-support.patch
  * firebird-2.5.2-CORE-4058.patch
  * firebird-2.5.2-icu49.patch
  * firebird-2.5.2-runlevel.patch
  * firebird-fix-unsigned-char.diff
  * firebird-s390x-fix_libdir.patch
  * ppc64-libdir.patch
- replace remaining patches by git based ones:
  * firebird-2.5.1-chown.patch
  - > allow-creating-buildRoot-as-non-root-user.patch
  * firebird-2.5.1-config.patch
  - > do-not-use-DatabaseAccess-Full-in-default-config.patch
  * firebird-2.5.1-disable.patch
  - > disable-xinetd-service-by-default.patch
  * firebird-2.5.2-gpidfile.patch
  - > fbguard-allow-creating-a-guard-pidfile.patch
  * firebird-2.5.2-init.patch
  - > use-killproc-in-stop-branch-of-SuSE-init-script.patch
    (remaining part not upstreamed)
  * firebird-2.5.2-isqlalign.patch
  - > Fixed-CORE-3431-ISQL-pads-UTF-8-data-incorrectly.patch
  * firebird-2.5.2-isqllocale.patch
  - > isql-fix-output-if-charset-is-different-from-locale.patch
  * firebird-2.5.2-isqlwidth.patch
  - > isql-fix-buffer-overflow-when-set-width-sets-bigger-.patch
  * firebird-2.5.2-pkgconfig.patch
  - > add-pkgconfig-files.patch
  * m68k-support.patch
  - > add-experimental-support-for-m68k-architecture.patch
- use xz compressed tarball
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashisms in scripts
- add patches:
  * Firebird-2.5.2.26539-0-fix-bashisms.patch
* Sat Jul  5 2014 coolo@suse.com
- install init script as executable
- fix the script
* Mon Feb 17 2014 ro@suse.de
- firebird-s390x-fix_libdir.patch: s390x uses lib64
* Tue Dec 17 2013 schwab@suse.de
- m68k-support.patch: add support for m68k
* Thu Dec  5 2013 mls@suse.de
- adapt for ppc64le
* Wed Aug 21 2013 fridrich.strba@suse.com
- firebird-2.5.2-pkgconfig.patch:
  fix fbembed.pc file to link with -lfbembed instead of -lfbclient
* Sun Jun  2 2013 mkubecek@suse.cz
- resolve file conflicts between packages
  * add explicit mutual conflict between -superserver and -classic
  * remove fbguard from -classic (it is shared between SS and SC)
* Fri Apr 12 2013 mkubecek@suse.cz
- config-guess-sub-update.patch:
  remove; attempt to patch these files would break build from
  subversion snapshots; remove both files instead and let
  libtoolize provide its own version
- reorder patches to keep the isql column alignment feature last
* Mon Apr  8 2013 schwab@suse.de
- firebird-fix-unsigned-char.diff:
  Compile with -fsigned-char
* Mon Apr  8 2013 matz@suse.de
- firebird-fix-unsigned-char.diff:
  fix for architectures where char is unsigned (aarch64 in this
  case, but applies everywhere)
- aarch64-support.patch:
  aarch64 doesn't need RISC_ALIGNMENT
* Sun Mar 24 2013 schwab@suse.de
- config-guess-sub-update.patch: update config.guess/sub for aarch64
- aarch64-support.patch: add support for aarch64
* Fri Mar  8 2013 mkubecek@suse.cz
- firebird-CORE-4058.patch:
  fix remote stack overflow (bnc#808268, CVE-2013-2492)
* Fri Jan 25 2013 coolo@suse.com
- fix license string
* Sun Nov 11 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26539 (2.5.2 final)
  * Optimizer level solution for CORE-2790/CORE-3449
  * CORE-2666: Make it possible to use API to do remote
    backups/restores
  * backup state lock should be released at latch timeout, else
    lock state accounting becomes inconsistent
  * CORE-3873: Server crashes while switching to the shadow if the
    disk I/O fault happens while flushing the cache
  * CORE-3860: Trace API: Faulty database filter crashes server
  * CORE-3875: GBak does not check correctly parameters and backups
    random database with -B ":"
  * CORE-3879: Make fb_lock_print a bit more handy
  * CORE-3656: Support for sweep information in Trace API
  * CORE-2668: Write note into log when automatic sweep is started
  * Enabled per-table runtime stats for sweeper (necessary for
    CORE-3656)
  * CORE-3884: Server crashes on preparing empty query when trace
    is enabled
  * CORE-3238: Makes GEN_UUID return a compliant RFC-4122 binary
    UUID
  * CORE-3887: CHAR_TO_UUID and UUID_TO_CHAR works different in
    big/little endian architectures - problem similar to CORE-2898
  * CORE-3895: High memory usage when PSQL code SELECT's from
    stored procedure which modified some data
  * Fixed the server crash in Stack::assign()
  * CORE-3902: Derived fields may not be optimized via an index
  * Fixed the broken (working as no-op) sweep in SuperServer
  * Use better name from trunk for CORE-3911
  * Restored the ODS level compatibility with v2.5.1 index keys,
    while using the "old good" index key format in new indices. It
    allows to claim that CORE-3675 and CORE-3853 are fixed (after
    migration via backup/restore) but still operate almost
    correctly with keys created in v2.5.1.
  * CORE-3912: segfault in superclassic
  * Better diagnostic (CORE-3786)
- firebird-2.5.2-icu49.patch:
  fix broken unicode collations (bnc#789171, CORE-3946)
* Wed Jul 25 2012 dvaleev@suse.com
- add libatomic-ops-devel on non x86 arches
- set libdir on powerpc correctly
* Sun Jul 22 2012 mkubecek@suse.cz
- firebird-2.5.2-runlevel.patch:
  don't start the daemon in runlevel 2
- add README.SUSE
* Wed Jun  6 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25494
  * Rolled back the ODS level solution for CORE-2709 as it causes
    cross-version compatibility issues (CORE-3853) as well as
    functional regressions (CORE-3675). Another solution is likely
    to be committed instead.
  * CORE-3769: The message 'Unknown tag (4) in isc_svc_query()
    results' appears when fbtracemgr is interrupted by Ctrl-C
* Sun Jun  3 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25492
  * CORE-3855: Blobs, inserted into GLOBAL TEMPORARY TABLE ON
    COMMIT DELETE ROWS, could be placed into newly allocated
    pages even if there is enough free place on some existing
    data page
  * isql: fix output if charset is different from locale
  * Backported fix of timed semaphores in 32-bit build
- firebird-2.5.2-isqlalign.patch:
  refresh
- firebird-2.5.2-isqllocale.patch:
  backported isql fix of output if locale different from charset
- firebird-2.5.2-isqlwidth.patch:
  backported fix for buffer overflow in isql if column width set
  wider that its natural size
* Fri May 25 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25488
  * CORE-3611: Wrong data while retrieving from CTEs (or derived
    tables) with same column names
  * CORE-3557: AV in engine when preparing query against dropping
    table (a post-fix)
  * add interpreter specification to generated scripts
  * fix broken isql history with libedit 3.0
  * CORE-3612: send errors to stderr
- firebird-2.5.1-shebang.patch:
  delete (committed to upstream)
- remove extern/SfIO from the source tarball: while it is probably
  covered by an open source license (EPL), the file stdio.h itself
  contains only an unfriendly copyright notice without any
  reference to the license; as it is needed only on Solaris, it
  seems easier to simply remove it
- use standardized tags for licence
* Fri May 18 2012 mkubecek@suse.cz
- spec file formatting
- add copyright to spec file
* Fri May 18 2012 mkubecek@suse.cz
- Switching to new Firebird version (2.5) and spec file. This
  obsoletes the previous changes file from version 2.1.
* Mon May 14 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25481
  * CORE-3539: TRACE: add ability for logging ERRORs that occur in
    runtime (lock conflicts, PK/UK/FK violations et al)
  * Trace errors raised by failed ON TRANSACTION ROLLBACK and ON
    DISCONNECT triggers
  * CORE-3598: TRACE: add statistics of actions that were after
    transaction finished
  * CORE-3814: SuperClassic server crashes when performing a
    database shutdown (FW=OFF)
  * fix regression introduced by patch for CORE-3777
  * CORE-3844: Validation not detects one specific case of index
    corruption
  * CORE-3841: Corrupted database after inserting rows
  * CORE-3839: Values disappearing from index
  * CORE-3845 : Interruption of 'heavy query' leads to 0 ms (zero
    duration) in it`s statistics in trace log
* Tue May  8 2012 mkubecek@suse.cz
- firebird-2.5.2-isqlalign.patch:
  replace locale based patch with backport from firebird 3.0
- firebird-2.5.2-gpidfile.patch:
  allow creating a pidfile for fbguard as well
- firebird-2.5.2-init.patch:
  use killproc and guard pidfile for "stop" branch
* Wed May  2 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25472
  * CORE-3819: Wrong service name to port address resolution in
    database connection string
  * CORE-3825: If an autocommit transaction (i.e. transaction
    started with isc_tpb_autocommit option) run DDL using EXECUTE
    STATEMENT it will produce a bugcheck 287 (Too many savepoints)
  * Make the conf. parameter DummyPacketInterval more accurate
  * CORE-3834: Usage of a NATURAL JOIN with a derived table crashes
    the server
- temporary fix for "stop" branch of init script
* Mon Apr 16 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26467
  * CORE-3806: Wrong data returned if a sub-query or a computed
    field refers to the base table in the ORDER BY clause
  * CORE-3807: Error "Invalid expression in the select list" can be
    unexpectedly raised if a string literal is used inside a GROUP
    BY clause in a multi-byte connection
  * CORE-3686: Incorrect (zero) values are reported for "acquire
    blocks" and "mutex wait" counters in the fb_lock_print output
  * CORE-3810 : isql: zero divide + coredump when use "-pag 0"
    command switch & set heading on inside .sql script
  * Rolled back the optimization committed recently due to the
    found regressions
  * CORE-3812 : Connection lost to database during massive dropping
    and altering primary keys of tables
  * Do not ignore possible OS level errors even if they seem
    unlikely to happen
* Mon Apr  2 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26456
  * CORE-2286: Selecting from MON$CALL_STACK within a Trigger or SP
    sometimes return 0 rows
  * CORE-3569: CHAR(32767) present in XSQLVAR with length 32765
  * CORE-3195: Concatenation to CHAR(32766/7) impossible
  * CORE-3625: MON$IO_STATS doesn't report page writes performed
    asynchronously (at the AST level)
  * CORE-3092: ROW_COUNT is not cleared before the singleton INSERT
    statement
  * CORE-1992: bad BLR -- invalid stream for union select
  * untracked AV due to CORE-3649
  * Undo patch for CORE-3468
  * CORE-3791: Performance degrades when actively working with
    databases bigger than the available RAM amount
  * CORE-3770: fbtracemgr loads CPU up to ~55%% when no activity is
    present
  * CORE-3799: with caller privileges option don't work with
    autonomous transaction option
  * CORE-3801: Warnings could be put twice in status-vector
  * CORE-3802: Firebird runs out of memory while restoring database
    backup
* Mon Mar 12 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26436
  * CORE-2457: UNICODE_CI internal gds software consistency
    check
  * CORE-3762: gsec returns 0 return code on some errors
  * CORE-3649: gbak deletes backup file even if error happens
    when it's already successfully closed
  * CORE-3777: Conversion error from string when using GROUP BY
  * CORE-3721: Multiuser server startup (/etc/init.d) script
    picks up the ISC_ variables if set
- remove dependency of firebird-devel on firebird
* Wed Feb 29 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26429
  * CORE-3761: Conversion error when using a blob as an argument
    for the EXCEPTION statement
  * CORE-3778: AV at connection shutdown
  * CORE-1997: Broken foreign key handling for multi-segmented
    index using multi-level collations
  * CORE-2457: UNICODE_CI internal gds software consistency check
* Wed Feb 15 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26425
  * CORE-3750: Error increasing limits on posix
* Mon Jan 30 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26424
  * CORE-3732: Segfault when closing attachment to database
  * CORE-3730: isc_dsql_exec_immed2() loses input parameter value with
    RETURNING clause
  * CORE-3733: GBAK fails to fix system generators while restoring
  * CORE-3736: WITH LOCK clause is allowed for users with read-only
    rights on some table, thus blocking others from updating this table
  * Stop db triggers in qli
- declare BuildRoot only when needed (< 1130)
- define version in one place rather than two
* Mon Jan 16 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26417
  * add system indices to avoid full table scans on system tables
  * CORE-3722: IS NOT DISTINCT FROM NULL doesn't use index
  * CORE-3727: Support C preprocessor flags in firebird build system
  * CORE-3599: Don't allow to drop RDB$ADMIN role
- removed obsolete firebird-2.5.2-libs.patch (in upstream now)
* Mon Jan  2 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26411
  * CORE-3862: Multiple update installs can cause problems
  * CORE-3697: String truncation error when selecting from a VIEW with
    UNION inside
  * CORE-3683: Wrong results if the recursive query contains an embedded
    GROUP BY clause
  * CORE-3671: JVM Access Violation when using Firebird Embedded
  * CORE-3238: Make GEN_UUID return a compliant RFC-4122 binary UUID
    and introduce CHAR_TO_UUID2 and UUID_TO_CHAR2 to convert UUIDs
    from/to string also complying with the RFC
  * CORE-3677: Stop utilities to export entrypoints
  * CORE-3646: Segmentation fault in Linux
  * CORE-3658: FBSVCMGR connects to server as OS user name rather than
    value of ISC_USER environment variable
* Wed Dec 14 2011 mkubecek@suse.cz
- update to upstream version 2.5.2.26397
  * CORE-3490: Concurrency problem when using named cursors
  * CORE-3690: Wrong warning message for ambiguous query
  * CORE-3680: EXECUTE BLOCK statement and ISC_DSQL_EXECUTE2() problem
  * CORE-927: Grants don't work for procedures used inside views
  * CORE-3692: Cannot drop a NOT NULL constraint on a field
    participating in the UNIQUE constraint
  * CORE-3601 - Incorrect TEXT BLOB charset transliteration on VIEW with
    trigger
- add libtool and pkg-config to BuildRequires
* Tue Nov 29 2011 mkubecek@suse.cz
- fixed include directory in pkg-config files
- set --prefix to /usr (shouldn't influence anything anyway)
* Mon Nov 28 2011 mkubecek@suse.cz
- provide pkg-config files for libfbclient and libfbembed
* Thu Nov 10 2011 mkubecek@suse.cz
- update to upstream version 2.5.2.26389
  * CORE-3646: Segmentation fault in multi-threaded program when using
    2.5.x client library on Linux
  * CORE-3650: Recreation of collation leads to FB "death"
  * CORE-3557: AV in engine when preparing query against dropping table
  * CORE-3579: Can't drop table when computed field depends on later
  * created another field
* Mon Oct 31 2011 mkubecek@suse.cz
- update to upstream version 2.5.2.26386
  * CORE-3636: Firebird 2.5.1 server crashes with Trace API
  * CORE-3631: Duplicate records with NULLs checked incorrectly
  * CORE-3627: Server crashes with access violation when inserting
    row into table with unique index
  * CORE-3600: temp files fb_query_xxxx remains after ISQL has been
    closed
  * CORE-3612: gfix-related services may loose error value in status
    vector in isc_service_start()
  * CORE-3610: Can insert DUPLICATE keys in UNIQUE index
* Tue Oct 18 2011 mkubecek@suse.cz
- compatibility with upstream tarball
* Fri Sep 30 2011 mkubecek@suse.cz
- fixes in init script, removed unneeded patch
* Thu Sep 29 2011 mkubecek@suse.cz
- fix baselibs.conf (libib_util.so moved to firebird)
* Thu Sep 29 2011 mkubecek@suse.cz
- add /srv/firebird directory
- restrict DatabaseAccess to /srv/firebird in default configuration
- move libib_util back to main server package (it depends on it)
- mark xinetd config file as config
- build with system editline
- don't fail install/upgrade if user or group creation fails
- rename isql and gstat to avoid conflict with other packages
* Tue Sep 27 2011 mkubecek@suse.cz
- common firebird-devel for header files and libib_util.so
- separate firebird-superserver package
- separate firebird-classic package
- build firebird-doc as noarch if possible (suse_version > 1110)
- restart on update (in postun)
- remove full version from patch names
- disable xinetd service by default
- move misc to _datadir
* Mon Sep 26 2011 mkubecek@suse.cz
- moved to BuildService
- removed %%debug_package
- build libfbclient2-32bit
- move libib_util.so to main package
- restart on update
- fixed typo init init script
* Mon Sep 19 2011 mike@mk-sys.cz
- update to 2.5.1.26358
* Fri Jun 24 2011 mike@mk-sys.cz
- update to 2.5.1.26319
* Wed May 25 2011 mike@mk-sys.cz
- update to 2.5.1.26285
- remove init scripts for other distributions
- simplify user/group creation
* Tue May 17 2011 mike@mk-sys.cz
- update to 2.5.1.26279
- compile against system ICU
- shared libraries moved into a subpackage
- create /var/run/firebird in init script
- add Short-Description into the init script
- fixed interpreter specification in support scripts
- full path tu useradd and groupadd in pre-install script
* Sat Mar 19 2011 mike@mk-sys.cz
- update to 2.5.1.26239
* Mon Jan 17 2011 mike@mk-sys.cz
- update to 2.5.0.26179
* Sun Nov  7 2010 mike@mk-sys.cz
- add useradd and groupadd to dependencies
* Fri Oct 15 2010 mike@mk-sys.cz
- update to 2.5.0.26098 (2.5.0 Release)
* Wed Aug  4 2010 mike@mk-sys.cz
- fixed typo in specfile (BuildRoot)
* Mon Aug  2 2010 mike@mk-sys.cz
- create firebird user and group in preinstall script
* Sun Aug  1 2010 mike@mk-sys.cz
- update to 2.5.0.26054
* Tue Jun  1 2010 mike@mk-sys.cz
- update to 2.5.0.26038
* Wed May 12 2010 mike@mk-sys.cz
- update to 2.5.0.26005
* Fri Apr  2 2010 mike@mk-sys.cz
- update to 2.5.0.25980
* Sat Mar 20 2010 mike@mk-sys.cz
- update to 2.5.0.25958
* Sat Feb  6 2010 mike@mk-sys.cz
- update to 2.5.0.25920
* Mon Jan  4 2010 mike@mk-sys.cz
- update to 2.5.0.25904
* Sun Dec  6 2009 mike@mk-sys.cz
- update to 2.5.0.25856
* Thu Nov 12 2009 mike@mk-sys.cz
- update to 2.5.0.25784
* Wed Oct 21 2009 mike@mk-sys.cz
- update to 2.5.0.25731
* Thu Oct  8 2009 mike@mk-sys.cz
- update to 2.5.0.25725
- small fixes to files sections
* Thu Sep 24 2009 mike@mk-sys.cz
- first version of the package
